@@ -46,7 +46,7 @@ use vars qw/@ISA @EXPORT @EXPORT_OK @EXPORT_TAGS
             $TIMEOUT @MODULES %MODULES %METHODS $AUTOLOAD
             @CURRENCY_RATES_MODULES $USE_EXPERIMENTAL_UA/;
 
-our $VERSION = '1.58'; # VERSION
+our $VERSION = '1.59'; # VERSION
 
 @CURRENCY_RATES_MODULES = qw/
     AlphaVantage
@@ -73,7 +73,6 @@ our $VERSION = '1.58'; # VERSION
     DWS
     Deka
     FTfunds
-    Fidelity
     Finanzpartner
     Fondsweb
     Fool
@@ -113,7 +112,7 @@ our $VERSION = '1.58'; # VERSION
 
 @ISA    = qw/Exporter/;
 @EXPORT = ();
-@EXPORT_OK = qw/fidelity troweprice asx tiaacref
+@EXPORT_OK = qw/troweprice asx tiaacref
                 currency_lookup/;
 @EXPORT_TAGS = ( all => [@EXPORT_OK]);
 
@@ -605,10 +604,10 @@ sub fetch {
   }
 
   # Temporary Counting - not concerned about return code
-  my $COUNT_URL =
-    'http://www.panix.com/~hd-fxsts/finance-quote.html?' . $method;
-  my $count_ua = LWP::UserAgent->new(timeout => 10);
-  my $count_response = $count_ua->head($COUNT_URL);
+  # my $COUNT_URL =
+  #   'http://www.panix.com/~hd-fxsts/finance-quote.html?' . $method;
+  # my $count_ua = LWP::UserAgent->new(timeout => 10);
+  # my $count_response = $count_ua->head($COUNT_URL);
 
   ### COUNT_URL: $COUNT_URL
   ### Code: $count_response->code
@@ -1695,7 +1694,6 @@ http://www.gnucash.org/
   Finance::Quote::DWS,
   Finance::Quote::Deka,
   Finance::Quote::FTfunds,
-  Finance::Quote::Fidelity,
   Finance::Quote::Finanzpartner,
   Finance::Quote::Fondsweb,
   Finance::Quote::Fool,
