@@ -25,7 +25,7 @@ use if DEBUG, 'Smart::Comments';
 use Web::Scraper;
 use Encode;
 
-our $VERSION = '1.58'; # VERSION
+our $VERSION = '1.59'; # VERSION
 
 my $FINANZPARTNER_URL = "https://www.finanzpartner.de/fi/";
 
@@ -63,6 +63,7 @@ sub finanzpartner
 
       my $processor = scraper {
         process 'span.kurs-m.pull-left', 'price[]' => 'TEXT';
+        process 'span.kurs.pull-left', 'price_alternative[]' => 'TEXT';
         process 'h1 > small', 'isin[]'             => 'TEXT';
         process 'div.col-md-2', 'date[]'           => 'TEXT';
         process 'h1 > span', 'name[]'              => 'TEXT';
@@ -70,6 +71,11 @@ sub finanzpartner
  
       my $data = $processor->scrape(decode_utf8 $reply->content);
 
+      # If price does not exists, then price_alternative should exist. In that case, put price_alternative into price.
+      if(exists $data->{price_alternative}) {
+        $data->{price} = $data->{price_alternative};
+      }
+
       ### data: $data
       
       die "Unexpected price format" unless exists $data->{price} and $data->{price}->[0] =~ /^([0-9.]+) ([A-Z]+)$/;
